@@ -69,7 +69,7 @@ style_active_file <- function() {
   }
   rstudioapi::modifyRange(
     c(1, 1, length(context$contents) + 1, 1),
-    paste0(ensure_last_is_empty(out), collapse = "\n"),
+    paste0(ensure_last_n_empty(out), collapse = "\n"),
     id = context$id
   )
   if (Sys.getenv("save_after_styling") == TRUE && context$path != "") {
