@@ -9,15 +9,8 @@
 #' @keywords internal
 compute_parse_data_nested <- function(text,
                                       transformers) {
-  parse_data <- tokenize(text) %>%
-    add_terminal_token_before() %>%
-    add_terminal_token_after() %>%
-    add_stylerignore() %>%
-    add_attributes_caching(transformers) %>%
-    drop_cached_children()
-
+  parse_data <- text_to_flat_pd(text, transformers)
   env_add_stylerignore(parse_data)
-
   parse_data$child <- rep(list(NULL), length(parse_data$text))
   pd_nested <- parse_data %>%
     nest_parse_data() %>%
@@ -28,6 +21,31 @@ compute_parse_data_nested <- function(text,
   pd_nested
 }
 
+#' Creates a flat parse table with minimal initialization
+#'
+#' Creates a flat parse table with minimal initialization and makes the parse
+#' table shallow where appropriate.
+#' @details
+#' This includes:
+#'
+#' * token before and after.
+#' * stylerignore attribute.
+#' * caching attributes.
+#' @inheritParams tokenize
+#' @inheritParams add_attributes_caching
+#' @details
+#' Note that the parse table might be shallow if caching is enabled and some
+#' values are cached.
+#' @keywords internal
+text_to_flat_pd <- function(text, transformers) {
+  tokenize(text) %>%
+    add_terminal_token_before() %>%
+    add_terminal_token_after() %>%
+    add_stylerignore() %>%
+    add_attributes_caching(transformers) %>%
+    drop_cached_children()
+}
+
 #' Add the block id to a parse table
 #'
 #' Must be after [nest_parse_data()] because requires a nested parse table as
@@ -47,7 +65,7 @@ add_cache_block <- function(pd_nested) {
 #' Drop all children of a top level expression that are cached
 #'
 #' Note that we do not cache top-level comments. Because package code has a lot
-#' of roxygen comments and each of them is a top level expresion, checking is
+#' of roxygen comments and each of them is a top level expression, checking is
 #' very expensive. More expensive than styling, because comments are always
 #' terminals.
 #' @param pd A top-level nest.
@@ -74,7 +92,7 @@ add_cache_block <- function(pd_nested) {
 #' As described in [cache_find_block()], expressions on the same line are always
 #' put into one block. If any element of a block is not cached, the block will
 #' be styled as a whole. If the parse table was made shallow (and the top level)
-#' expresion is still marked as non-terminal, `text` will never be used in the
+#' expression is still marked as non-terminal, `text` will never be used in the
 #' transformation process and eventually lost. Hence, we must change the top
 #' level expression to a terminal. It will act like a comment in the sense that
 #' it is a fixed `text`.
@@ -105,18 +123,28 @@ drop_cached_children <- function(pd) {
 #' Find the pos ids to keep
 #'
 #' To make a parse table shallow, we must know which ids to keep.
-#' `split(cumsum(pd_parent_first$parent < 1))` above puts comments with negative
-#' parents in the same block as proceeding expressions. `find_pos_id_to_keep()`
-#' must hence always keep comments. We did not use
-#' `split(cumsum(pd_parent_first$parent < 1))` because then every comment is an
-#' expression on its own and processing takes much longer for typical roxygen
-#' annotated code
+#' `split(cumsum(pd_parent_first$parent == 0))` above puts comments with negative
+#' parents in the same block as proceeding expressions (but also with positive).
+#' `find_pos_id_to_keep()` must hence always keep negative comments. We did not
+#' use `split(cumsum(pd_parent_first$parent < 1))` because then every top-level
+#' comment is an expression on its own and processing takes much longer for
+#' typical roxygen annotated code.
 #' @param pd A temporary top level nest where the first expression is always a
 #'   top level expression, potentially cached.
+#' @details
+#' Note that top-level comments **above** code have negative parents
+#' (the negative value of the parent of the code expression that follows after,
+#' another comment might be in the way though), all comments that are not top
+#' level have positive ids. All comments for which no code follows afterwards
+#' have parent 0.
+#' @examples
+#' styler:::get_parse_data(c("#", "1"))
+#' styler:::get_parse_data(c("c(#", "1)"))
+#' styler:::get_parse_data(c("", "c(#", "1)", "#"))
 #' @keywords internal
 find_pos_id_to_keep <- function(pd) {
   if (pd$is_cached[1]) {
-    pd$pos_id[c(TRUE, pd[-1L, "token"] == "COMMENT")]
+    pd$pos_id[pd$parent <= 0]
   } else {
     pd$pos_id
   }
@@ -129,6 +157,7 @@ find_pos_id_to_keep <- function(pd) {
 #' few illustrative examples below.
 #' @details
 #' Styling is on by default when you run styler.
+#'
 #' - To mark the start of a sequence where you want to turn styling off, use
 #'   `# styler: off`.
 #' - To mark the end of this sequence, put `# styler: on` in your code. After
@@ -239,12 +268,18 @@ add_terminal_token_before <- function(pd_flat) {
 
 #' Initialise variables related to caching
 #'
+#' Note that this does function must be called in [compute_parse_data_nested()]
+#' and we cannot wait to initialize this attribute until [apply_transformers()],
+#' where all other attributes are initialized with
+#' [default_style_guide_attributes()] (when using [tidyverse_style()]) because
+#' for cached code, we don't build up the nested structure and leave it shallow
+#' (to speed up things), see also [drop_cached_children()].
 #' @param transformers A list with transformer functions, used to check if
 #'   the code is cached.
 #' @describeIn add_token_terminal Initializes `newlines` and `lag_newlines`.
 #' @keywords internal
 add_attributes_caching <- function(pd_flat, transformers) {
-  pd_flat$block  <- rep(NA, nrow(pd_flat))
+  pd_flat$block <- rep(NA, nrow(pd_flat))
   pd_flat$is_cached <- rep(FALSE, nrow(pd_flat))
   if (cache_is_activated()) {
     is_parent <- pd_flat$parent == 0
