@@ -1,6 +1,6 @@
 #' Style a roxygen code example that may contain dontrun and friends
 #'
-#' Parses roxygen2 comments into code, breaks it into dont* (dontrun, dontest,
+#' Parses roxygen2 comments into code, breaks it into dont* (dontrun, donttest,
 #' dontshow) and run sections and processes each segment individually using
 #' [style_roxygen_example_snippet()].
 #' @inheritParams parse_transform_serialize_r
@@ -67,8 +67,20 @@ style_roxygen_example_snippet <- function(code_snippet,
     code_snippet <- decomposed$code
     mask <- decomposed$mask
   }
-  code_snippet <- post_parse_roxygen(code_snippet) %>%
-    parse_transform_serialize_r(transformers, warn_empty = FALSE)
+  code_snippet <- post_parse_roxygen(code_snippet)
+
+  cache_is_active <- cache_is_activated()
+  is_cached <- is_cached(code_snippet, transformers)
+  if (!is_cached || !cache_is_active) {
+    code_snippet <- code_snippet %>%
+      parse_transform_serialize_r(transformers, warn_empty = FALSE)
+  } else {
+    code_snippet <- ensure_last_n_empty(code_snippet, n = 0)
+  }
+
+  if (!is_cached && cache_is_active) {
+    cache_write(code_snippet, transformers)
+  }
 
   if (is_dont) {
     code_snippet <- c(mask, code_snippet, "}")
