@@ -67,7 +67,7 @@ wrap_multiline_curly <- function(pd, indent_by, space_after = 1, key_token) {
     pd, which(pd$token == key_token)[1]
   )
   next_terminal <- next_terminal(pd[to_be_wrapped_expr_with_child, ])$text
-  requires_braces <- if_for_while_part_requires_braces(pd, key_token)
+  requires_braces <- if_for_while_part_requires_braces(pd, key_token) && !any(pd$stylerignore)
   if (requires_braces | next_terminal == "return") {
     closing_brace_ind <- which(pd$token == key_token)[1]
     pd$spaces[closing_brace_ind] <- 1L
@@ -94,7 +94,8 @@ wrap_multiline_curly <- function(pd, indent_by, space_after = 1, key_token) {
 wrap_else_multiline_curly <- function(pd, indent_by = 2, space_after = 0) {
   if (contains_else_expr(pd) &&
     pd_is_multi_line(pd) &&
-    contains_else_expr_that_needs_braces(pd)) {
+    contains_else_expr_that_needs_braces(pd) &&
+    !any(pd$stylerignore)) {
     else_idx <- which(pd$token == "ELSE")
     pd$spaces[else_idx] <- 1L
     all_to_be_wrapped_ind <- seq2(else_idx + 1L, nrow(pd))
