@@ -1,5 +1,4 @@
 test_that("caching utils make right blocks with semi-colon", {
-
   blocks_simple_uncached <- compute_parse_data_nested(c("1 + 1", "2; 1+1")) %>%
     dplyr::mutate(is_cached = FALSE) %>%
     cache_find_block()
@@ -33,12 +32,12 @@ test_that("caching utils make right blocks with comments", {
   blocks_simple_uncached <- compute_parse_data_nested(text) %>%
     dplyr::mutate(is_cached = c(
       FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, TRUE, FALSE,
-      TRUE, FALSE, FALSE, FALSE)
-    ) %>%
+      TRUE, FALSE, FALSE, FALSE
+    )) %>%
     cache_find_block()
   expect_equal(blocks_simple_uncached, c(1, 1, 1, 1, 1, 1, 1, 2, 2, 3, 4, 4, 4))
 
-  text <- '
+  text <- "
    ### comment
    x = 1
    y = 2 # comment
@@ -47,21 +46,20 @@ test_that("caching utils make right blocks with comments", {
 
    # something something
    tau1 = 1 # here?
-   '
+   "
   blocks_simple_cached <- compute_parse_data_nested(text) %>%
     dplyr::mutate(is_cached = c(
-      FALSE, FALSE, FALSE, FALSE, FALSE, TRUE, FALSE, FALSE, FALSE, FALSE)
-    ) %>%
+      FALSE, FALSE, FALSE, FALSE, FALSE, TRUE, FALSE, FALSE, FALSE, FALSE
+    )) %>%
     cache_find_block()
   expect_equal(blocks_simple_cached, c(1, 1, 1, 1, 1, 2, 2, 2, 2, 2))
-
 })
 
 
 test_that("blank lines are correctly identified", {
   on.exit(clear_testthat_cache())
-  clear_testthat_cache()
-  activate_testthat_cache()
+  fresh_testthat_cache()
+
   text <- c(
     "1 + 1",
     "",
@@ -120,11 +118,14 @@ test_that("caching utils make right blocks with comments", {
 
 test_that("Individual comment expressions are not cached", {
   on.exit(clear_testthat_cache())
-  clear_testthat_cache()
-  cache_activate("testthat")
+  fresh_testthat_cache()
   style_text(c("# g", "1"))
   cache_info <- cache_info()
   # because output text is cached as a whole, there should be 2 cached
   # expressions now
   expect_equal(cache_info$n, 2)
 })
+
+test_that("cache is deactivated at end of caching related testthat file", {
+  expect_false(cache_is_activated())
+})
