@@ -29,22 +29,32 @@ capture.output(test_that("Cache management works", {
 
 test_that("top-level test: Caches top-level expressions efficiently on style_text()", {
   on.exit(clear_testthat_cache())
-  clear_testthat_cache()
+  fresh_testthat_cache()
   text <- test_path("cache-with-r-cache/mlflow-1-in.R") %>%
     readLines()
-  activate_testthat_cache()
-  benchmark <- system.time(text_styled <- style_text(text))
-  full_cached_benchmark <- system.time(style_text(text_styled))
-  expect_lt(full_cached_benchmark['elapsed'], .1)
+  benchmark <- system.time(text_styled <- as.character(style_text(text)))
+  expect_equal(text, text_styled)
+  full_cached_benchmark <- system.time(text_styled2 <- as.character(style_text(text_styled)))
+  expect_equal(text, text_styled2)
+
   # modify one function declaration
-  text_styled[2] <-gsub(")", " )", text_styled[2], fixed = TRUE)
-  partially_cached_benchmark <- system.time(style_text(text_styled))
-  cache_deactivate()
-  not_cached_benchmark <- system.time(style_text(text_styled))
-  expect_lt(
-    partially_cached_benchmark['elapsed'] * 3,
-    not_cached_benchmark['elapsed']
+  text_styled[2] <- gsub(")", " )", text_styled[2], fixed = TRUE)
+  partially_cached_benchmark <- system.time(
+    text_cached_partially <- as.character(style_text(text_styled))
   )
+  expect_equal(text, text_cached_partially)
+  cache_deactivate()
+  not_cached_benchmark <- system.time(
+    text_not_cached <- as.character(style_text(text_styled))
+  )
+  expect_equal(text, text_not_cached)
+
+  skip_on_cran()
+  expect_lt(
+    partially_cached_benchmark["elapsed"] * 2.5,
+    not_cached_benchmark["elapsed"]
+  )
+  expect_lt(full_cached_benchmark["elapsed"] * 65, benchmark["elapsed"])
 })
 
 
@@ -74,11 +84,14 @@ capture.output(test_that("cached expressions are displayed propperly", {
   )
 }))
 
+test_that("cache is deactivated at end of caching related testthat file", {
+  expect_false(cache_is_activated())
+})
+
 
 test_that("When expressions are cached, number of newlines between them are preserved", {
   on.exit(clear_testthat_cache())
-  clear_testthat_cache()
-  activate_testthat_cache()
+  fresh_testthat_cache()
   text <- c(
     "1 + 1",
     "",
@@ -91,20 +104,9 @@ test_that("When expressions are cached, number of newlines between them are pres
     "function() NULL"
   )
   # add to cache
-  expect_equal(
-    text[1:4],
-    as.character(style_text(text[1:4]))
-  )
+  expect_equal(text[1:4], as.character(style_text(text[1:4])))
   # applied cache
-  expect_equal(
-    text[1:4],
-    as.character(style_text(text[1:4]))
-  )
+  expect_equal(text[1:4], as.character(style_text(text[1:4])))
 
-  expect_equal(
-    text,
-    as.character(style_text(text))
-  )
+  expect_equal(text, as.character(style_text(text)))
 })
-
-
