@@ -3,14 +3,16 @@ context("scope argument")
 test_that("no indention manipulation but spaces manipulation", {
   expect_warning(test_collection(
     "scope_argument", "scope_spaces",
-    transformer = style_text, style = tidyverse_style, scope = "spaces"), NA)
+    transformer = style_text, style = tidyverse_style, scope = "spaces"
+  ), NA)
 })
 
 test_that("no line-break manipulation", {
   expect_warning(test_collection(
     "scope_argument", "scope_indention",
     transformer = style_text,
-    style = tidyverse_style, scope = "indention"), NA)
+    style = tidyverse_style, scope = "indention"
+  ), NA)
 })
 
 
@@ -19,7 +21,8 @@ test_that("no token manipulation", {
     "scope_argument", "scope_line_breaks",
     transformer = style_text,
     style = tidyverse_style,
-    scope = "line_breaks"), NA)
+    scope = "line_breaks"
+  ), NA)
 })
 
 test_that("no space manipulation", {
@@ -27,7 +30,8 @@ test_that("no space manipulation", {
     "scope_argument", "scope_tokens",
     transformer = style_text,
     style = tidyverse_style,
-    scope = "tokens"), NA)
+    scope = "tokens"
+  ), NA)
 })
 
 
@@ -36,7 +40,6 @@ test_that("no manipulation at all", {
     "scope_argument", "scope_none",
     transformer = style_text,
     style = tidyverse_style,
-    scope= "none"), NA)
+    scope = "none"
+  ), NA)
 })
-
-
